@@ -113,8 +113,8 @@ def black_periods_to_content_periods(black_periods):
     """
     content_periods = []
     previous_period_end = 0
-    for i, black_period in enumerate(black_periods):
-        if i == 0 and black_period["start"] == 0:
+    for black_period in black_periods:
+        if black_period["start"] == 0:
             # first black period starts at 0, so we don't need to split it
             previous_period_end = black_period["end"]
             continue
@@ -124,7 +124,7 @@ def black_periods_to_content_periods(black_periods):
             "end": black_period["start"],
         }
         content_periods.append(current_period)
-        previous_period_end = black_period["start"]
+        previous_period_end = black_period["end"]
 
     # add a final, open-ended one
     content_periods.append({"start": previous_period_end})
@@ -137,6 +137,7 @@ def cut_part(
     output_directory=None,
     start=None,
     end=None,
+    no_copy=False,
     progress=False,
     verbose=False,
 ):
@@ -150,11 +151,16 @@ def cut_part(
         start = 0
 
     if end is not None:
-        to_args = ["-to", str(end)]
+        to_args = ["-t", str(end - start)]
     else:
         end = ""
         to_args = []
 
+    if no_copy:
+        codec_args = ["-c:v", "libx264", "-c:a", "aac"]
+    else:
+        codec_args = ["-c", "copy"]
+
     suffix = f"{start}-{end}.mkv"
     prefix = os.path.splitext(os.path.basename(input_file))[0]
     output_file = os.path.join(output_directory, f"{prefix}_{suffix}")
@@ -163,13 +169,12 @@ def cut_part(
         "ffmpeg",
         "-hide_banner",
         "-y",
-        "-i",
-        input_file,
         "-ss",
         str(start),
+        "-i",
+        input_file,
         *to_args,
-        "-c",
-        "copy",
+        *codec_args,
         "-map",
         "0",
         output_file,
@@ -221,6 +226,12 @@ def main():
         "--output-directory",
         help="Set the output directory. Default is the current working directory.",
     )
+    parser.add_argument(
+        "--no-split", action="store_true", help="Don't split the video into segments."
+    )
+    parser.add_argument(
+        "--no-copy", action="store_true", help="Don't stream-copy, but re-encode the video."
+    )
     parser.add_argument(
         "-p", "--progress", action="store_true", help="Show a progress bar on stderr"
     )
@@ -228,7 +239,7 @@ def main():
         "-v",
         "--verbose",
         action="store_true",
-        help="Print verbose info to stderr, and JSON of black periods to stdout",
+        help="Print verbose info to stderr, and JSON of black and content periods to stdout",
     )
 
     cli_args = parser.parse_args()
@@ -260,14 +271,18 @@ def main():
             )
         )
 
-    # cut the individual periods to files
-    for content_period in content_periods:
-        cut_part(
-            cli_args.input,
-            output_directory=cli_args.output_directory,
-            start=content_period["start"],
-            end=content_period.get("end"),
-        )
+    if not cli_args.no_split:
+        # cut the individual periods to files
+        for content_period in content_periods:
+            cut_part(
+                cli_args.input,
+                output_directory=cli_args.output_directory,
+                start=content_period["start"],
+                end=content_period.get("end"),
+                no_copy=cli_args.no_copy,
+                progress=cli_args.progress,
+                verbose=cli_args.verbose,
+            )
 
 
 if __name__ == "__main__":
